************************************
The sherpa.optmethods.optfcts module
************************************

.. currentmodule:: sherpa.optmethods.optfcts

.. automodule:: sherpa.optmethods.optfcts

  .. rubric:: Functions

  .. autosummary::
     :toctree: api

     difevo
     difevo_lm
     difevo_nm
     grid_search
     lmdif
     minim
     montecarlo
     neldermead
